@@ -440,11 +440,13 @@ class ArgSuite(Generic[ArgType]):
         else:
             self._validate_fields(arg_class)
             self._arg_classes.append(arg_class)
-            try:
-                comments = self.get_comments(arg_class)
-            except OSError as e:
-                logger.warning(f"Failed parsing comments from the source inspection: {e}.\n Continue without them.")
-                comments = {}
+            comments = {}
+            for b in (*arg_class.__mro__[-1:0:-1], arg_class):
+                if b is not object:
+                    try:
+                        comments.update(**self.get_comments(b))
+                    except Exception as e:
+                        logger.warning(f"Failed parsing comments for {b} from the source inspection: {e}.\n Continue without them.")
             for raw_arg_name, arg_type in _annotations(arg_class).items():
                 arg_name = f'{prefix}{raw_arg_name}'
                 try:
@@ -485,7 +487,7 @@ class ArgSuite(Generic[ArgType]):
                         field_meta = FieldMeta(comment=comments.get(raw_arg_name, ''), default=default, type=arg_type)
                         kwargs = handler.gen_kwargs(field_meta)
                         # apply user override to the argument object
-                        kwargs.__dict__.update(**vars(arg_class).get(f'_{raw_arg_name}', {}))
+                        kwargs.__dict__.update(getattr(arg_class, f'_{raw_arg_name}', {}))
                         if hasattr(kwargs, 'choices'):
                             logger.info(f"'{arg_name}': 'choices' {kwargs.choices} specified, removing 'metavar'.")
                             del kwargs.metavar  # 'metavar' would override 'choices' which makes the help message less helpful
