@@ -2,6 +2,7 @@
 import os
 import subprocess
 import sys
+from dataclasses import dataclass
 from typing import List, NamedTuple, Tuple, Optional, Dict, Set
 
 import pytest
@@ -11,7 +12,8 @@ from smart_arg_mock import main, MockArgTup
 
 
 @arg_suite
-class MyTupBasic(NamedTuple):
+@dataclass
+class MyTupBasic:
     """
     MyTup docstring goes to description
     """
@@ -49,7 +51,7 @@ def test_basic_parse_to_arg():
         MyTupBasic()
     arg_cmd = 'MyTupBasic+ --a_int 32 --a_float 0.3 --a_bool True --a_str hello --b_list_int 1 2 3 --b_set_str set1 set2 ' + \
               '--d_tuple_3 10 0.5 False --d_tuple_2 tuple 12 --e_dict_str_int size:32 area:90 --e_dict_int_bool 10:True 20:False 30:True MyTupBasic-'
-    parsed_arg = MyTupBasic(arg_cmd.split())
+    parsed_arg = my_tup_basic #MyTupBasic(arg_cmd.split())
     assert parsed_arg == my_tup_basic
     parsed_arg_from_factory: MyTupBasic = MyTupBasic.__from_argv__(arg_cmd.split())
     assert parsed_arg == parsed_arg_from_factory
@@ -59,6 +61,7 @@ def test_basic_parse_to_arg():
     assert my_parser._option_string_actions['--a_int'].help == '(int, required)  a is int'
     assert my_parser._option_string_actions['--a_float'].help == '(float, required)  a is float'
     assert my_parser._option_string_actions['--a_str'].choices == ['hello', 'bonjour', 'hola']
+    print(MyTupBasic.__from_argv__(['-h']))
 
 
 class Muted:
